<?php

namespace Drupal\pbs_media_manager\Plugin\QueueWorker;

use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\pbs_media_manager\ApiContentManagerBase;
use Drupal\pbs_media_manager\EpisodeManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes Asset data from the Media Manager API to PBS Video media entities.
 *
 * Queue items are added by cron processing.
 *
 * @QueueWorker(
 *   id = "pbs_media_manager.queue.assets",
 *   title = @Translation("Media Manager Assets processor"),
 *   cron = {"time" = 60},
 *   weight = 10
 * )
 *
 * @see pbs_media_manager_cron()
 * @see \Drupal\Core\Annotation\QueueWorker
 * @see \Drupal\Core\Annotation\Translation
 */
class AssetsQueueWorker extends QueueWorkerBase implements
  ContainerFactoryPluginInterface {

  /**
   * PBS Media Manager logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  private $logger;

  /**
   * Episode manager.
   *
   * @var \Drupal\pbs_media_manager\ApiContentManagerBase
   */
  private $assetManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration,
    $plugin_id,
    $plugin_definition,
    LoggerChannelInterface $logger,
    ApiContentManagerBase $asset_manager
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->logger = $logger;
    $this->assetManager = $asset_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('logger.channel.pbs_media_manager'),
      $container->get('pbs_media_manager.asset_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($item): void {
    $this->assetManager->addOrUpdateAssetContent($item);
  }

}
