<?php

namespace Drupal\pbs_media_manager\Plugin\QueueWorker;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\pbs_media_manager\EpisodeManager;
use Drupal\pbs_media_manager\EpisodeManagerNoChangelog;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes Episode data from the Media Manager API to Episode nodes.
 *
 * Queue items are added by cron processing.
 *
 * @QueueWorker(
 *   id = "pbs_media_manager.queue.episodes",
 *   title = @Translation("Media Manager Episodes processor"),
 *   cron = {"time" = 60},
 *   weight = 10
 * )
 *
 * @see pbs_media_manager_cron()
 * @see \Drupal\Core\Annotation\QueueWorker
 * @see \Drupal\Core\Annotation\Translation
 */
class EpisodesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * PBS Media Manager logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  private $logger;

  /**
   * The media manager settings config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;


  /**
   * Episode manager.
   *
   * @var \Drupal\pbs_media_manager\EpisodeManager
   */
  private $episodeManager;

  /**
   * Episode manager.
   *
   * @var \Drupal\pbs_media_manager\EpisodeManagerNoChangelog
   */
  private $episodeManagerNoChangelog;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration,
    $plugin_id,
    $plugin_definition,
    LoggerChannelInterface $logger,
    ConfigFactoryInterface $config_factory,
    EpisodeManager $episode_manager,
    EpisodeManagerNoChangelog $episode_manager_no_changelog
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->logger = $logger;
    $this->config = $config_factory->get('pbs_media_manager.settings');
    $this->episodeManager = $episode_manager;
    $this->episodeManagerNoChangelog = $episode_manager_no_changelog;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('logger.channel.pbs_media_manager'),
      $container->get('config.factory'),
      $container->get('pbs_media_manager.episode_manager'),
      $container->get('pbs_media_manager.episode_manager_no_changelog')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($item): void {

    $changelog = $this->config->get('shows.queue.changelog');

    if ($changelog) {
      $this->episodeManager->addOrUpdateEpisode($item);
    }
    else {
      $this->episodeManagerNoChangelog->addOrUpdateEpisode($item);
    }
  }

}
