<?php

namespace Drupal\pbs_media_manager\Plugin\QueueWorker;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\pbs_media_manager\SeasonManager;
use Drupal\pbs_media_manager\SeasonManagerNoChangelog;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes Season data from the Media Manager API to Season nodes.
 *
 * Queue items are added by cron processing.
 *
 * @QueueWorker(
 *   id = "pbs_media_manager.queue.seasons",
 *   title = @Translation("Media Manager Seasons processor"),
 *   cron = {"time" = 60},
 *   weight = 0
 * )
 *
 * @see pbs_media_manager_cron()
 * @see \Drupal\Core\Annotation\QueueWorker
 * @see \Drupal\Core\Annotation\Translation
 */
class SeasonsQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * PBS Media Manager logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  private $logger;

  /**
   * The media manager settings config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;


  /**
   * Season manager.
   *
   * @var \Drupal\pbs_media_manager\SeasonManager
   */
  private $seasonManager;

  /**
   * Season manager.
   *
   * @var \Drupal\pbs_media_manager\SeasonManagerNoChangelog
   */
  private $seasonManagerNoChangelog;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration,
    $plugin_id,
    $plugin_definition,
    LoggerChannelInterface $logger,
    ConfigFactoryInterface $config_factory,
    SeasonManager $season_manager,
  SeasonManagerNoChangelog $season_manager_no_changelog
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->logger = $logger;
    $this->config = $config_factory->get('pbs_media_manager.settings');
    $this->seasonManager = $season_manager;
    $this->seasonManagerNoChangelog = $season_manager_no_changelog;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('logger.channel.pbs_media_manager'),
      $container->get('config.factory'),
      $container->get('pbs_media_manager.season_manager'),
      $container->get('pbs_media_manager.season_manager_no_changelog')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($item): void {

    $changelog = $this->config->get('shows.queue.changelog');

    if ($changelog) {
      $this->seasonManager->addOrUpdateSeason($item);
    }
    else {
      $this->seasonManagerNoChangelog->addOrUpdateSeason($item);
    }
  }

}
