<?php

namespace Drupal\pbs_media_manager\Plugin\QueueWorker;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\pbs_media_manager\ShowManager;
use Drupal\pbs_media_manager\ShowManagerNoChangelog;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes Show data from the Media Manager API to Show nodes.
 *
 * Queue items are added by cron processing.
 *
 * @QueueWorker(
 *   id = "pbs_media_manager.queue.shows",
 *   title = @Translation("Media Manager Shows processor"),
 *   cron = {"time" = 60},
 *   weight = -10
 * )
 *
 * @see pbs_media_manager_cron()
 * @see \Drupal\Core\Annotation\QueueWorker
 * @see \Drupal\Core\Annotation\Translation
 */
class ShowsQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * PBS Media Manager logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  private $logger;

  /**
   * The media manager settings config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Show manager.
   *
   * @var \Drupal\pbs_media_manager\ShowManager
   */
  private $showManager;

  /**
   * Show manager no changelog.
   *
   * @var \Drupal\pbs_media_manager\ShowManagerNoChangelog
   */
  private $showManagerNoChangelog;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration,
    $plugin_id,
    $plugin_definition,
    LoggerChannelInterface $logger,
    ConfigFactoryInterface $config_factory,
    ShowManager $show_manager,
    ShowManagerNoChangelog $show_manager_no_changelog
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config_factory->get('pbs_media_manager.settings');
    $this->logger = $logger;
    $this->showManager = $show_manager;
    $this->showManagerNoChangelog = $show_manager_no_changelog;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('logger.channel.pbs_media_manager'),
      $container->get('config.factory'),
      $container->get('pbs_media_manager.show_manager'),
      $container->get('pbs_media_manager.show_manager_no_changelog')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($item): void {

    $changelog = $this->config->get('shows.queue.changelog');

    if ($changelog) {
      $this->showManager->addOrUpdateShow($item);
    }
    else {
      $this->showManagerNoChangelog->addOrUpdateShow($item);
    }
  }

}
